==> 5.5.2.tar.gz: webid-eident-plugin-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdEIdentPlugin",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdEIdentPlugin", targets: ["WebIdEIdentPluginWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackages/webid-plugin-core-spm.git",
            .exact("12.3.3")
        ),
        .package(
            name: "AusweisApp2",
            url: "https://github.com/Governikus/AusweisApp2-SDK-iOS",
            .exact("1.26.5")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdEIdentPlugin",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/internal/de/webid-solutions/WebIdEIdentPlugin/5.5.2/WebIdEIdentPlugin.framework-v5.5.2.zip",
            checksum: "601751a1ba921eb1f91a07bff2288ed37f78d5fd19a5e155dc70926e5ef0c2fd"
        ),
        .target(
            name: "WebIdEIdentPluginWrapper",
            dependencies: [
                .target(name: "WebIdEIdentPlugin"),
                // [target dependecies here]
                
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
                .product(name: "AusweisApp2", package: "AusweisApp2"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)

==> 6.5.0.tar.gz: webid-eident-plugin-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdEIdentPlugin",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdEIdentPlugin", targets: ["WebIdEIdentPluginWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackageRedesignV4/webid-plugin-core-spm.git",
            .exact("13.5.0")
        ),
        .package(
            name: "AusweisApp2",
            url: "https://github.com/Governikus/AusweisApp2-SDK-iOS",
            .exact("1.26.5")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdEIdentPlugin",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/redesign-v4/de/webid-solutions/WebIdEIdentPlugin/6.5.0/WebIdEIdentPlugin.framework-v6.5.0.zip",
            checksum: "874b0de58192730cd76012154d1681aa516ec7b02a87f035ca2443885f577080"
        ),
        .target(
            name: "WebIdEIdentPluginWrapper",
            dependencies: [
                .target(name: "WebIdEIdentPlugin"),
                // [target dependecies here]
                
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
                .product(name: "AusweisApp2", package: "AusweisApp2"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)
